@@ -1,7 +1,7 @@
 /*
     have.h -- include headers which are known to exist
-    Copyright (C) 1998-2005 Ivo Timmermans <ivo@tinc-vpn.org>
-                  2003-2005 Guus Sliepen <guus@tinc-vpn.org>
+    Copyright (C) 1998-2005 Ivo Timmermans
+                  2003-2006 Guus Sliepen <guus@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -43,6 +43,10 @@
 #include <inttypes.h>
 #endif
 
+#ifdef HAVE_ALLOCA_H
+#include <alloca.h>
+#endif
+
 /* Include system specific headers */
 
 #ifdef HAVE_SYSLOG_H
