@@ -1,8 +1,8 @@
 /*
     avl_tree.h -- header file for avl_tree.c
     Copyright (C) 1998 Michael H. Buselli
-                  2000-2005 Ivo Timmermans <ivo@tinc-vpn.org>,
-                  2000-2005 Guus Sliepen <guus@tinc-vpn.org>
+                  2000-2005 Ivo Timmermans,
+                  2000-2006 Guus Sliepen <guus@tinc-vpn.org>
                   2000-2005 Wessel Dankers <wsl@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
@@ -29,7 +29,7 @@
     library for inclusion into tinc (http://www.tinc-vpn.org/) by
     Guus Sliepen <guus@tinc-vpn.org>.
 
-    $Id: avl_tree.h 1439 2005-05-04 18:09:30Z guus $
+    $Id: avl_tree.h 1452 2006-04-26 13:52:58Z guus $
 */
 
 
