@@ -1,7 +1,7 @@
 /*
     connection.h -- header for connection.c
-    Copyright (C) 2000-2005 Guus Sliepen <guus@tinc-vpn.org>,
-                  2000-2005 Ivo Timmermans <ivo@tinc-vpn.org>
+    Copyright (C) 2000-2006 Guus Sliepen <guus@tinc-vpn.org>,
+                  2000-2005 Ivo Timmermans
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: connection.h 1439 2005-05-04 18:09:30Z guus $
+    $Id: connection.h 1456 2006-08-08 13:21:08Z guus $
 */
 
 #ifndef __TINC_CONNECTION_H__
@@ -32,17 +32,20 @@
 #define OPTION_TCPONLY		0x0002
 #define OPTION_PMTU_DISCOVERY	0x0004
 
-typedef struct connection_status_t {
-	int pinged:1;				/* sent ping */
-	int active:1;				/* 1 if active.. */
-	int connecting:1;			/* 1 if we are waiting for a non-blocking connect() to finish */
-	int termreq:1;				/* the termination of this connection was requested */
-	int remove:1;				/* Set to 1 if you want this connection removed */
-	int timeout:1;				/* 1 if gotten timeout */
-	int encryptout:1;			/* 1 if we can encrypt outgoing traffic */
-	int decryptin:1;			/* 1 if we have to decrypt incoming traffic */
-	int mst:1;				/* 1 if this connection is part of a minimum spanning tree */
-	int unused:23;
+typedef union connection_status_t {
+	struct {
+		int pinged:1;				/* sent ping */
+		int active:1;				/* 1 if active.. */
+		int connecting:1;			/* 1 if we are waiting for a non-blocking connect() to finish */
+		int termreq:1;				/* the termination of this connection was requested */
+		int remove:1;				/* Set to 1 if you want this connection removed */
+		int timeout:1;				/* 1 if gotten timeout */
+		int encryptout:1;			/* 1 if we can encrypt outgoing traffic */
+		int decryptin:1;			/* 1 if we have to decrypt incoming traffic */
+		int mst:1;				/* 1 if this connection is part of a minimum spanning tree */
+		int unused:23;
+	};
+	uint32_t value;
 } connection_status_t;
 
 #include "edge.h"
@@ -59,7 +62,7 @@ typedef struct connection_t {
 
 	int socket;					/* socket used for this connection */
 	long int options;			/* options for this connection */
-	struct connection_status_t status;	/* status info */
+	connection_status_t status;	/* status info */
 	int estimated_weight;		/* estimation for the weight of the edge for this connection */
 	struct timeval start;		/* time this connection was started, used for above estimation */
 	struct outgoing_t *outgoing;	/* used to keep track of outgoing connections */
@@ -91,7 +94,13 @@ typedef struct connection_t {
 	int tcplen;					/* length of incoming TCPpacket */
 	int allow_request;			/* defined if there's only one request possible */
 
-	time_t last_ping_time;		/* last time we saw some activity from the other end */
+	char *outbuf;				/* metadata output buffer */
+	int outbufstart;			/* index of first meaningful byte in output buffer */
+	int outbuflen;				/* number of meaningful bytes in output buffer */
+	int outbufsize;				/* number of bytes allocated to output buffer */
+
+	time_t last_ping_time;		/* last time we saw some activity from the other end or pinged them */
+	time_t last_flushed_time;	/* last time buffer was empty. Only meaningful if outbuflen > 0 */
 
 	avl_tree_t *config_tree;	/* Pointer to configuration tree belonging to him */
 } connection_t;
